<?php

/**************************************************
	//エンドポイントの一覧
	https://api.vineapp.com/timelines/users/{ユーザーID}		//ユーザーのタイムライン
	https://api.vineapp.com/timelines/popular					//人気動画のタイムライン
	https://api.vineapp.com/timelines/tags/{タグ名}				//ハッシュタグのタイムライン
	https://api.vineapp.com/timelines/promoted					//Vineスタッフのピックアップ
	https://api.vineapp.com/timelines/users/{ユーザーID}/likes		//ユーザーがお気に入りした動画の一覧
	https://api.vineapp.com/timelines/users/{ユーザーID}/reposts	//ユーザーがRevineした動画の一覧
	https://api.vineapp.com/timelines/channels/{チャンネルID}		//チャンネルのタイムライン
	https://api.vineapp.com/timelines/global						//Vine全体のタイムライン (要認証)
	https://api.vineapp.com/timelines/venues/{ベニューID}			//ベニュー(場所)のタイムライン
**************************************************/

	// 認証キー
	$auth_key = '' ;

	// リクエストURL
	$request_url = 'https://api.vineapp.com/timelines/promoted' ;

	// BASIC認証のリクエスト
	$curl = curl_init() ;
	curl_setopt( $curl , CURLOPT_URL , $request_url ) ;
	curl_setopt( $curl , CURLOPT_HEADER, 1 ) ; 
	if( $auth_key )
	{
		curl_setopt( $curl , CURLOPT_HTTPHEADER , array( 'vine-session-id: ' . $auth_key . "\r\n" ) ) ;
	}
	curl_setopt( $curl , CURLOPT_SSL_VERIFYPEER , false ) ;
	curl_setopt( $curl , CURLOPT_RETURNTRANSFER , true ) ;
	curl_setopt( $curl , CURLOPT_TIMEOUT , 5 ) ;
	$res1 = curl_exec( $curl ) ;
	$res2 = curl_getinfo( $curl ) ;
	curl_close( $curl ) ;

	// 取得したデータ
	$json = substr( $res1, $res2['header_size'] ) ;			// 取得したデータ(JSONなど)
	$header = substr( $res1, 0, $res2['header_size'] ) ;		// レスポンスヘッダー (検証に利用したい場合にどうぞ)

	// HTML用
	$html = '' ;

	// JSONデータをオブジェクト形式に変換する
	$obj = json_decode( $json ) ;

	// 実行結果の出力
	$html .= '<h2>実行結果</h2>' ;

	// エラー判定
	if( !$obj || !isset($obj->data->records) || empty($obj->data->records) )
	{
		$html .= '<p>データを取得できませんでした…。設定を再確認して下さい。</p>' ;
	}
	else
	{
		// 説明
		$html .= '<p>下記のタイムラインを取得しました。</p>' ;

		// 解析
		foreach( $obj->data->records as $item )
		{
			// 各データの整理
			$userId = (string)$item->userId ;		// ユーザーID (文字列にキャストしないと末尾の数値が丸まる…)
			$username = $item->username ;		// ユーザー名
			$avatarUrl = ( isset($item->avatarUrl) ) ? $item->avatarUrl : '' ;		// アバター画像
			$postId = $item->postId ;		// 動画のID
			$created = $item->created ;		// 投稿日時
			$videoUrl = $item->videoUrl ;		// 動画ファイルのURL
			$permalinkUrl = $item->permalinkUrl ;		// パーマリンク
			$thumbnailUrl = ( isset($item->thumbnailUrl) ) ? $item->thumbnailUrl : '' ;		// サムネイル画像
			$description = ( isset($item->description) ) ? $item->description : '' ;		// 紹介文
			$likes_count = ( isset($item->likes->count) ) ? $item->likes->count : 0 ;		// ライク数
			$loops_count = ( isset($item->loops->count) ) ? $item->loops->count : 0 ;		// ループ数
			$comments_count = ( isset($item->comments->count) ) ? $item->comments->count : 0 ;		// コメント数
			$reposts_count = ( isset($item->reposts->count) ) ? $item->reposts->count : 0 ;		// Revineの数

			// 日付の整形
			$created = date( 'Y/m/d H:i' , strtotime( $created ) ) ;

			// ブラウザに出力
			$html .= '<dl>' ;
			$html .= 	'<dt>ユーザーID</dt>' ;
			$html .= 		'<dd><a href="https://vine.co/u/' . $userId . '" target="_blank">' . $userId . '</a></dd>' ;
			$html .= 	'<dt>ユーザー名</dt>' ;
			$html .= 		'<dd>' . $username . '</dd>' ;

			// 紹介文
			if( $description )
			{
				$html .= 	'<dt>紹介文</dt>' ;
				$html .= 		'<dd>' . $description . '</dd>' ;
			}

			// アイコン画像
			if( $avatarUrl )
			{
				$html .= 	'<dt>アイコン画像</dt>' ;
				$html .= 		'<dd><img class="_img" src="' . str_replace( 'http' , 'https' , $avatarUrl ) . '" width="75" height="auto"></dd>' ;
			}

			$html .= 	'<dt>動画のID</dt>' ;
			$html .= 		'<dd>' . $postId . '</dd>' ;
			$html .= 	'<dt>動画のURLアドレス</dt>' ;
			$html .= 		'<dd>' . $videoUrl . '</dd>' ;
			$html .= 	'<dt>パーマリンク</dt>' ;
			$html .= 		'<dd><a href="' . $permalinkUrl . '" target="_blank">' . $permalinkUrl . '</a></dd>' ;
			$html .= 	'<dt>投稿日時</dt>' ;
			$html .= 		'<dd>' . $created . '</dd>' ;

			// サムネイル画像
			if( $thumbnailUrl )
			{
				$html .= 	'<dt>サムネイル画像</dt>' ;
				$html .= 		'<dd><img class="_img" src="' . str_replace( 'http' , 'https' , $thumbnailUrl ) . '" width="200" height="auto"></dd>' ;
			}

			// 動画の紹介文
			if( $description )
			{
				$html .= 	'<dt>動画の紹介文</dt>' ;
				$html .= 		'<dd>' . $description . '</dd>' ;
			}

			$html .= 	'<dt>ライク数</dt>' ;
			$html .= 		'<dd>' . number_format( $likes_count ) . '</dd>' ;
			$html .= 	'<dt>ループ数</dt>' ;
			$html .= 		'<dd>' . number_format( $loops_count ) . '</dd>' ;
			$html .= 	'<dt>コメント数</dt>' ;
			$html .= 		'<dd>' . number_format( $comments_count ) . '</dd>' ;
			$html .= 	'<dt>Revineの数</dt>' ;
			$html .= 		'<dd>' . number_format( $reposts_count ) . '</dd>' ;
			$html .= '</dl>' ;
		}
	}

	// 取得したデータ
	$html .= '<h2>取得したデータ</h2>' ;
	$html .= '<p>下記のデータを取得できました。</p>' ;
	$html .= 	'<h3>JSON</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $json . '</textarea></p>' ;
	$html .= 	'<h3>レスポンスヘッダー</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $header . '</textarea></p>' ;

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Vine APIでタイムラインを取得するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/vine-api-matome

	* 動作確認
	https://syncer.jp/vine-api-matome/demo/get-timeline.php

	* 最終更新日時
	2015/08/03 13:03

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/vine-api-matome">配布元: Syncer</a></p>






</body>
</html>
